@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2025-06-13
+# Release 2025-08-11
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.8.2
+MAKERESOLVEDEB_VERSION=1.8.3
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -431,6 +431,7 @@ process_20() {
     create_directory "${RESOLVE_BASE_DIR}"/share
     create_directory "${RESOLVE_BASE_DIR}"/Fairlight
     create_directory "${RESOLVE_BASE_DIR}"/Extras
+    create_directory "${RESOLVE_BASE_DIR}"/Apple\ Immersive
 
     # Copy objects
     copy_object "${UNPACK_DIR}"/bin "${RESOLVE_BASE_DIR}"
@@ -482,6 +483,7 @@ chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /opt/resolve/Fairlight
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
 chmod -R a+rw /opt/resolve/Extras
+chmod -R a+rw /opt/resolve/Apple\ Immersive
 EOF
 }
 
